@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2019-2023 -- leonerd@leonerd.org.uk
 
-package Object::Pad 0.800;
+package Object::Pad 0.801;
 
 use v5.14;
 use warnings;
@@ -847,6 +847,18 @@ warning can be quieted by using C<ADJUSTPARAMS> instead. Additionally, a
 warning may be printed on code that attempts to access the params hashref via
 the C<@_> array.
 
+I<Since version 0.801> in a future version of this module, C<ADJUST> blocks
+may be implemented as true blocks and will not permit out-of-block control
+flow. At present, they are implemented as one full CV per block, but a warning
+is emitted if out-of-block control flow is attempted.
+
+   ADJUST {
+      return;
+   }
+
+   Using return to leave an ADJUST block is discouraged and will be removed
+   in a later version at FILE line LINE.
+
 =head2 ADJUST :params
 
    ADJUST :params ( :$var1, :$var2, ... ) {
@@ -1203,14 +1215,17 @@ more visually distinct.
 sub VERSION
 {
    my $pkg = shift;
-   my ( $ver ) = @_;
 
-   $pkg->SUPER::VERSION( $ver );
+   my $ret = $pkg->SUPER::VERSION( @_ );
 
-   $ver = version->parse( $ver );
+   if( @_ ) {
+      my $ver = version->parse( @_ );
 
-   # Only bother to store it if it's >= v0.800
-   $^H{"Object::Pad/imported-version"} = $ver->numify if $ver ge v0.800;
+      # Only bother to store it if it's >= v0.800
+      $^H{"Object::Pad/imported-version"} = $ver->numify if $ver ge v0.800;
+   }
+
+   return $ret;
 }
 
 sub import
